//
//  AlertDialogViewController.m
//  scummvm
//
//  Created by Ilya Levin on 17/10/2015.
//
//

#import "MenuViewController.h"
#import "AlertDialogViewController.h"
#import "UIStoryboard+scummVMAdditions.h"
#import "UIButton+MTAdditions.h"
#import "UILabel+MTAdditions.h"

@interface AlertDialogViewController ()

@property (retain, nonatomic) IBOutlet UILabel *lblMessage;
@property (retain, nonatomic) IBOutlet UIButton *btnLeft;
@property (retain, nonatomic) IBOutlet UIButton *btnMid;
@property (retain, nonatomic) IBOutlet UIButton *btnRight;


@property (nonatomic, strong) NSString* message;
@property (nonatomic) NSUInteger buttonNumber;
@property (nonatomic, strong) NSString* buttonTitle1;
@property (nonatomic, strong) NSString* buttonTitle2;
@property (nonatomic, strong) NSString* buttonTitle3;
@property (nonatomic) shared_ptr<Enhanced::AlertDialogListener> listner;


@end

@implementation AlertDialogViewController

+(instancetype)alertDialogViewControllerWithMessage:(NSString *)message buttonNum:(NSUInteger)buttonNumber button1:(NSString *)button1 button2:(NSString *)button2 button3:(NSString *)button3 listner:(shared_ptr<Enhanced::AlertDialogListener>)listner
{
    AlertDialogViewController* alertViewController = [[UIStoryboard mainStoryboard] instantiateViewControllerWithIdentifier:@"AlertDialogViewController"];
    
    alertViewController.message = message;
    alertViewController.buttonNumber = buttonNumber;
    alertViewController.buttonTitle1 = button1;
    alertViewController.buttonTitle2 = button2;
    alertViewController.buttonTitle3 = button3;

    alertViewController.listner = listner;
    alertViewController.modalPresentationStyle = UIModalPresentationOverCurrentContext;
    
    return alertViewController;
}

-(void)viewDidLoad
{
    [super viewDidLoad];
    
    if (self.nativeUIInterface->hasFontwithLowercase()){
        self.lblMessage.text = self.message;
    }
    else{ // Forcing capital letters if needed
        [_lblMessage setText:[self.message uppercaseString]];
    }
    
    [self configureForButtonNumber:self.buttonNumber];
    
    [self.lblMessage configureWithTheme];
    [self.btnMid configureWithTheme:YES];
    [self.btnLeft configureWithTheme:YES];
    [self.btnRight configureWithTheme:YES];
    
    self.view.backgroundColor = [[UIColor blackColor] colorWithAlphaComponent:0.6]; // Greyed out background
}

-(void)configureForButtonNumber:(NSUInteger)buttonNumber
{
    switch (buttonNumber) {
        case 1:
            [self.btnMid setTitle:self.buttonTitle1 forState:UIControlStateNormal];
            self.btnLeft.hidden = YES;
            self.btnRight.hidden = YES;
            break;
        case 2:
            [self.btnLeft setTitle:self.buttonTitle1 forState:UIControlStateNormal];
            [self.btnRight setTitle:self.buttonTitle2 forState:UIControlStateNormal];
            self.btnMid.hidden = YES;
            break;
            
        case 3:
            [self.btnLeft setTitle:self.buttonTitle1 forState:UIControlStateNormal];
            [self.btnMid setTitle:self.buttonTitle2 forState:UIControlStateNormal];
            [self.btnRight setTitle:self.buttonTitle3 forState:UIControlStateNormal];

            break;
            
        default:
            break;
    }
}

-(void)selectedOption:(int)selectedOption
{
    [buttonClickPlayer() play];

    shared_ptr<Enhanced::AlertDialogListener> listner1 = self.listner;
    
    dispatch_async(dispatch_get_main_queue(), ^{
        listner1->onClick(selectedOption);
    });

}

- (IBAction)leftButtonTapped:(id)sender {

//    dispatch_async(dispatch_get_main_queue(), ^{
//        self.listner->onClick(0);

    [self selectedOption:0];
//    });
    [self dismissViewControllerAnimated:NO completion:nil];


}

- (IBAction)midButtonTapped:(id)sender {

    int clickValue = (self.buttonNumber == 1)?0:1;

    [self selectedOption:clickValue];
    [self dismissViewControllerAnimated:NO completion:nil];

//    if (self.buttonNumber == 1) {
////        self.listner->onClick(0);
//        clickValue = 0;
//    }
//    else // case 3 buttons
//    {
//        clickValue = 1;
////        self.listner->onClick(1);
//    }
    

}

- (IBAction)rightButtonTapped:(id)sender
{

    int clickValue = (self.buttonNumber == 2)?1:2;

    [self selectedOption:clickValue];
    [self dismissViewControllerAnimated:NO completion:nil];

//    if (self.buttonNumber == 2) {
//        clickValue = 1;
//        self.listner->onClick(1);
//    }
//    else // case 3 buttons
//    {
//        clickValue = 2;
//        self.listner->onClick(2);
//    }
    

}

@end
