//
//  ExtraItemsListViewController.m
//  scummvm
//
//  Created by ilya on 12/18/15.
//
//

#import "Strings.h"
#import "NSStringAdditions.h"
#import "NSBundle+MTAdditions.h"
#import "UIStoryboard+scummVMAdditions.h"
#import "UIActivityViewController+MTAdditions.h"
#import "UIFont+ScummVMAdditions.h"

#import "iPhoneNativeMPViewController.h"
#import "ExtraItemsListViewController.h"

#ifdef USE_GA

#import "GAI.h"
#import "GAIDictionaryBuilder.h"
#import "GAIFields.h"

#endif

using namespace Enhanced;

@interface ExtraItemsListViewController ()
@property (nonatomic) vector<ExtraItem> extraItems;
@property (nonatomic, strong) UIDocumentInteractionController* interactionController;

@end

@implementation ExtraItemsListViewController

+(instancetype)extrasListWithItems:(vector<ExtraItem>)items
{
    ExtraItemsListViewController* extraViewController = [[UIStoryboard mainStoryboard] instantiateViewControllerWithIdentifier:@"ExtraItemsListViewController"];
    
    NSMutableArray* itemStrings = [[NSMutableArray alloc] init];
    
    std::for_each(items.begin(), items.end(), ^(ExtraItem item){
        [itemStrings addObject:[NSString stringWithCPPWString:item.mTitle]];
    });
    
    extraViewController.items = itemStrings;
    extraViewController.extraItems = items;
    
    return extraViewController;
}


- (void)viewDidLoad {
    
    [super viewDidLoad];
    
#ifdef USE_GA
    
    id<GAITracker> tracker = [[GAI sharedInstance] defaultTracker];
    [tracker set:kGAIScreenName value:@"Extras Screen"];
    [tracker send:[[GAIDictionaryBuilder createScreenView] build]];
    
#endif
    
    self.tableView.alwaysBounceVertical = NO; //disable scrolling when not needed
}

-(void)configureButtonTitles
{
    NSString* backTitle = [NSString stringWithCPPWString:Strings::getString(StringId::back)];
    
    self.negativeButton = backTitle;
    
    [super configureButtonTitles];
}

-(void)indexPathTapped:(NSIndexPath *)indexPath
{
    ExtraItem item = self.extraItems[indexPath.row];
    
    switch (item.mType)
    {
        case VIDEO: {
            // play video
            [self playVideoItem:item];
            break;
        }
        case AUDIO: {
            // play audio
            [self playAudioItem:item];
            break;
        }
        case LOCAL_FILE: {
            // try to open file
            [self openLocalFile:item];
            break;
        }
        case LINK: {
            // open link
            [self openLinkItem:item];
            break;
        }
        case LIST: {
            // show sublist of extras
            [self showSublist:item];
            break;
        }
    }
    
    [self.tableView deselectRowAtIndexPath:indexPath animated:YES];
}

-(void)playVideoItem:(ExtraItem)item
{
    //[musicBGPlayer() pause]; // pause background music
    
    NSURL* url = [[NSBundle currentGameBundle] URLForResource:[NSString stringWithCPPString:item.mContent] withExtension:nil];
    
    iPhoneNativeMPViewController* moviePlayerVC = [[iPhoneNativeMPViewController alloc] initWithContentURL:url];
    moviePlayerVC.moviePlayer.controlStyle = MPMovieControlStyleNone;
    
    [self presentViewController:moviePlayerVC animated:YES completion:^{
        [[moviePlayerVC moviePlayer] play];
    }];
}

-(void)playAudioItem:(ExtraItem)item
{
    
    //[musicBGPlayer() pause]; // pause background music
    
    NSURL* url = [[NSBundle currentGameBundle] URLForResource:[NSString stringWithCPPString:item.mContent] withExtension:nil];
    
    AVAudioPlayer* audioPlayer =[[AVAudioPlayer alloc] initWithContentsOfURL:url error: nil];
    
    [audioPlayer play];
}

-(void)openLinkItem:(ExtraItem)item
{
    NSURL* url = [NSURL URLWithString:[NSString stringWithCPPString:item.mContent]];
    
    [[UIApplication sharedApplication] openURL:url];
}

-(void)openLocalFile:(ExtraItem)item
{
    NSURL* url = [[NSBundle currentGameBundle] URLForResource:[NSString stringWithCPPString:item.mContent] withExtension:nil];
    
    UIDocumentInteractionController* documentInteractionController = [UIDocumentInteractionController interactionControllerWithURL:url];
    
    [documentInteractionController presentOpenInMenuFromRect:self.tableView.frame inView:self.view animated:YES];
    self.interactionController = documentInteractionController;
}

-(void)showSublist:(ExtraItem)item
{
    ExtraItemsListViewController* extralist = [ExtraItemsListViewController extrasListWithItems:item.mSubItems];
    
    [self.navigationController pushViewController:extralist animated:NO];
}

-(IBAction)share:(id)sender
{
    UIActivityViewController* activityViewController = [UIActivityViewController shareMyAppActivityViewController];
    BOOL isIpad = [UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPad;
    
    if (isIpad) {
        UIPopoverController* popoverController = [[UIPopoverController alloc] initWithContentViewController:activityViewController];
        
        [popoverController presentPopoverFromRect:[sender frame] inView:self.view permittedArrowDirections:UIPopoverArrowDirectionAny animated:YES];
    }
    else
    {
        [self presentViewController:activityViewController animated:YES completion:nil];
    }
}

-(void)negativeTapped:(id)sender
{
    [self.navigationController popViewControllerAnimated:NO];
    [buttonClickPlayer() play];
}

-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSString* title = self.items[indexPath.row];
    
    CGRect screenRect = [[UIScreen mainScreen] bounds];
    CGSize maximumLabelSize = CGSizeMake (screenRect.size.width - 150*[UIStoryboard relativeScale], CGFLOAT_MAX);
    CGRect textRect = [title boundingRectWithSize:maximumLabelSize
                                          options:NSStringDrawingUsesLineFragmentOrigin| NSStringDrawingUsesFontLeading
                                       attributes:@{NSFontAttributeName:[UIFont mt_themeFontOfAppropriateSize]}
                                          context:nil];
    
    return textRect.size.height + 15; // padding
}

@end
